function OpswatCASB () {
	this.options = {
		timeout: 10000,
		serverPort: 11369,
		serverAddress: 'eapi.opswatgears.com',
		apiUrl: '/opswat/devinfo',
		callback: undefined,
		data: undefined,
		sessionId: undefined
	};
	
}

const OPSWAT_PUBLIC_KEY = "-----BEGIN PUBLIC KEY-----\nMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC7LW5XWfdxqgFjfW72jM3z6vvp\n8X/9M5UvJf0X8WVOjZ0wp4IYlKeCuk2chn0tTNpT25cNEjyKOMHaMzaPMdZ/axt1\n0jo85QzGF47WU9ifnIKY6XCKZ/KsTPbK9Pj4w33bK+hTxHhYg6QK2mhtglt57ZOz\nH8YqongNin2yCT4GnwIDAQAB\n-----END PUBLIC KEY-----";

OpswatCASB.prototype = {
	version: '1.0',
	jsonp: function (options) {
		//Replace properties from user input:
		for ( var i in options ) {
			this.options[i] = options[i];
		}
		this._callJsonp();
	},
	_callJsonp: function () {
		var opswatCASB = this;
		var url = 'https://' + opswatCASB.options.serverAddress + ':' + opswatCASB.options.serverPort + opswatCASB.options.apiUrl + "?session_id=" + opswatCASB.options.sessionId;
		$.ajax({
			url: url,
			dataType: "jsonp",
			data: JSON.stringify(opswatCASB.options.data),
			timeout: opswatCASB.options.timeout,
		    success: function(data) {
		         opswatCASB._handleSuccessResponse(data);
		    },
		    error: function(data){
		    	//Timeout request:
		    	//console.log( 'data: ', data )
  				opswatCASB._handleErrorResponse(data);
			}
		});
	},
	_verifyJwtToken: function (token) {
		try {
			var data = KJUR.jws.JWS.parseJWS(token);
		    var isValid = KJUR.jws.JWS.verify(token, OPSWAT_PUBLIC_KEY, ['RS256']);
		    return isValid;
		  } catch (ex) {
		  	console.log("Validation failed ", ex)
			return false;
		  }
	},
	_handleSuccessResponse: function (response) {
		if(this.options.callback != undefined)
		{
			var token = response.data;
			try {
				var JwtData = KJUR.jws.JWS.parse(token);
				
				//Verify the JWT token and session ID
			    var isValid = KJUR.jws.JWS.verify(token, OPSWAT_PUBLIC_KEY, [JwtData.headerObj.alg]);
			    if (!isValid && sessionId != JwtData.payloadObj.session_id) {
			    	var jsonResponse = {code: -32,
								description: 'Verification failed'};
					this.options.callback(jsonResponse);
					return;
			    }
			    
			    //Handle callback
			    this.options.callback(JwtData.payloadObj);
			  } catch (ex) {
			  	console.log("Validation failed ", ex)
			  	var jsonResponse = {code: -32,
								description: 'Verification failed'};
				this.options.callback(jsonResponse);
			  }
		}
	},
	_handleErrorResponse: function (data) {
		if(this.options.callback != undefined)
		{
			var jsonResponse = {code: -31,
								description: 'Not found'};
			if(data.statusText == "timeout")
				jsonResponse = {code: -30,
								description: 'Timeout'};
			this.options.callback(jsonResponse);
		}
	}
}